Module: Marionetta::Commandable
- Included in:
- DirectorySync, Manipulators::Deployer, Manipulators::Puppet
- Defined in:
- lib/marionetta/commandable.rb
Instance Attribute Summary collapse
-
#cmd ⇒ Object
writeonly
To use your own alternative to
CommandRunneryou can set an object of your choice via the.cmd=method.
Instance Attribute Details
#cmd=(value) ⇒ Object
To use your own alternative to CommandRunner you can
set an object of your choice via the .cmd= method.
10 11 12 |
# File 'lib/marionetta/commandable.rb', line 10 def cmd=(value) @cmd = value end |